@@ -133,7 +133,6 @@ class ModulePermanentxss(Attack):
                             description += ".\nWarning: Content-Security-Policy is present!"
 
                         await self.add_high(
-                            request_id=request.path_id,
                             finding_class=finding,
                             request=evil_request,
                             parameter=parameter.name,
@@ -181,6 +180,7 @@ class ModulePermanentxss(Attack):
                     self.successful_xss = module.successful_xss
                     self.tried_xss = module.tried_xss
 
+    # pylint: disable=too-many-positional-arguments
     async def attempt_exploit(self, method, payloads, injection_request, parameter: str, taint: str, output_request):
         timeouted = False
         page = injection_request.path
@@ -216,7 +216,6 @@ class ModulePermanentxss(Attack):
                     anom_msg = Messages.MSG_PARAM_TIMEOUT.format(xss_param.display_name)
 
                 await self.add_medium(
-                    request_id=injection_request.path_id,
                     finding_class=ResourceConsumptionFinding,
                     request=evil_request,
                     info=anom_msg,
@@ -265,7 +264,6 @@ class ModulePermanentxss(Attack):
                         description += ".\nWarning: Content-Security-Policy is present!"
 
                     await self.add_high(
-                        request_id=injection_request.path_id,
                         finding_class=finding,
                         request=evil_request,
                         parameter=xss_param.display_name,
@@ -304,7 +302,6 @@ class ModulePermanentxss(Attack):
                         anom_msg = Messages.MSG_PARAM_500.format(xss_param.display_name)
 
                     await self.add_high(
-                        request_id=injection_request.path_id,
                         finding_class=InternalErrorFinding,
                         request=evil_request,
                         info=anom_msg,
